@@ -1,5 +1,6 @@
 from upyog.imports import *
 from upyog.utils import *
 from upyog.os import *
-from upyog.cli import *
+from upyog.cli import call_parse
+from upyog.cli import Param as P
 from upyog.image import *
