@@ -24,7 +24,7 @@ from enum import Enum
 from functools import partial, reduce
 from pathlib import Path
 from pprint import pprint
-from types import SimpleNamespace
+from types import SimpleNamespace, MethodType
 from typing import *
 
 import fastcore.all as fastcore
@@ -43,6 +43,7 @@ from rich.traceback import install
 from tqdm.auto import tqdm
 from typing_extensions import Literal
 
+ImageFile.LOAD_TRUNCATED_IMAGES = True
 PathLike = Union[str, Path]
 
 logger = logger.opt(colors=True)
